Decimal

Struct Decimal 

pub struct Decimal {
    pub exponent: i32,
    pub mantissa: i64,
}
Represents a scaled decimal number.

Fields

exponent: i32mantissa: i64

Implementations

Source

impl Decimal

pub fn new(exponent: i32, mantissa: i64) -> Decimal

pub fn from_string(value: &str) -> Result<Decimal>

If the field is of type decimal, the value resulting from the conversion is normalized. The reason for this is that the exponent and mantissa must be predictable when operators are applied to them individually. A decimal value is normalized by adjusting the mantissa and exponent so that the integer remainder after dividing the mantissa by 10 is not zero: mant % 10 != 0. For example 100 would be normalized as 1 * 10^2. If the mantissa is zero, the normalized decimal has a zero mantissa and a zero exponent.

Errors

Returns error if string is incorrect format.

pub fn from_float(value: f64) -> Result<Decimal>

Creates decimal value from float.

Errors

Returns error if number is not finite.

pub fn to_string(&self) -> String

If the number is in fact an integer, it is converted as if was of integer type. Otherwise, the number is represented by an integer part and a decimal part separated by a decimal point (‘.’). Each part is a sequence of digits ‘0’ – ‘9’. There must be at least one digit on each side of the decimal point. If the number is negative it is preceded by a minus sign (‘-’). The integer part must not have any leading zeroes.

pub fn to_float(&self) -> f64